CfgEnv

Struct CfgEnv 

#[non_exhaustive]
pub struct CfgEnv<SPEC = SpecId> {
Show 22 fields pub spec: SPEC, pub gas_params: GasParams, pub chain_id: u64, pub tx_chain_id_check: bool, pub limit_contract_code_size: Option<usize>, pub limit_contract_initcode_size: Option<usize>, pub disable_nonce_check: bool, pub max_blobs_per_tx: Option<u64>, pub blob_base_fee_update_fraction: Option<u64>, pub tx_gas_limit_cap: Option<u64>, pub memory_limit: u64, pub disable_balance_check: bool, pub disable_block_gas_limit: bool, pub disable_eip3541: bool, pub disable_eip3607: bool, pub disable_eip7623: bool, pub disable_base_fee: bool, pub disable_priority_fee_check: bool, pub disable_fee_charge: bool, pub enable_amsterdam_eip8037: bool, pub amsterdam_eip7708_disabled: bool, pub amsterdam_eip7708_delayed_burn_disabled: bool,
}
EVM configuration

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
spec: SPEC

Specification for EVM represent the hardfork

CfgEnv::new_with_spec is going to set both gas params and spec.

As GasParams is spec dependent, it is recommended to use one of following function to set both of them. CfgEnv::set_spec_and_mainnet_gas_params, CfgEnv::with_mainnet_gas_params, CfgEnv::with_mainnet_gas_params

gas_params: GasParams

Gas params for the EVM. Use CfgEnv::set_gas_params to set the gas params. If gas_params was not set it will be set to the default gas params for the spec.

chain_id: u64

Chain ID of the EVM. Used in CHAINID opcode and transaction’s chain ID check.

Chain ID is introduced EIP-155.

tx_chain_id_check: bool

Whether to check the transaction’s chain ID.

If set to false, the transaction’s chain ID check will be skipped.

limit_contract_code_size: Option<usize>

Contract code size limit override.

If None, the limit will be determined by the SpecId (EIP-170 or EIP-7954) at runtime. If Some, this specific limit will be used regardless of SpecId.

Useful to increase this because of tests.

limit_contract_initcode_size: Option<usize>

Contract initcode size limit override.

If None, the limit will check if limit_contract_code_size is set. If it is set, it will double it for a limit. If it is not set, the limit will be determined by the SpecId (EIP-170 or EIP-7954) at runtime.

Useful to increase this because of tests.

disable_nonce_check: bool

Skips the nonce validation against the account’s nonce

max_blobs_per_tx: Option<u64>

Blob max count. EIP-7840 Add blob schedule to EL config files.

If this config is not set, the check for max blobs will be skipped.

blob_base_fee_update_fraction: Option<u64>

Blob base fee update fraction. EIP-4844 Blob base fee update fraction.

If this config is not set, the blob base fee update fraction will be set to the default value. See also CfgEnv::blob_base_fee_update_fraction.

Default values for Cancun is primitives::eip4844::BLOB_BASE_FEE_UPDATE_FRACTION_CANCUN and for Prague is primitives::eip4844::BLOB_BASE_FEE_UPDATE_FRACTION_PRAGUE.

tx_gas_limit_cap: Option<u64>

Configures the gas limit cap for the transaction.

If None, default value defined by spec will be used.

Introduced in Osaka in EIP-7825: Transaction Gas Limit Cap with initials cap of 30M.

memory_limit: u64

A hard memory limit in bytes beyond which OutOfGasError::Memory cannot be resized.

In cases where the gas limit may be extraordinarily high, it is recommended to set this to a sane value to prevent memory allocation panics.

Defaults to 2^32 - 1 bytes per EIP-1985.

disable_balance_check: bool

Skip balance checks if true

Adds transaction cost to balance to ensure execution doesn’t fail.

By default, it is set to false.

disable_block_gas_limit: bool

There are use cases where it’s allowed to provide a gas limit that’s higher than a block’s gas limit.

To that end, you can disable the block gas limit validation.

By default, it is set to false.

disable_eip3541: bool

EIP-3541 rejects the creation of contracts that starts with 0xEF

This is useful for chains that do not implement EIP-3541.

By default, it is set to false.

disable_eip3607: bool

EIP-3607 rejects transactions from senders with deployed code

In development, it can be desirable to simulate calls from contracts, which this setting allows.

By default, it is set to false.

disable_eip7623: bool

EIP-7623 increases calldata cost.

This EIP can be considered irrelevant in the context of an EVM-compatible L2 rollup, if it does not make use of blobs.

By default, it is set to false.

disable_base_fee: bool

Disables base fee checks for EIP-1559 transactions

This is useful for testing method calls with zero gas price.

By default, it is set to false.

disable_priority_fee_check: bool

Disables “max fee must be less than or equal to max priority fee” check for EIP-1559 transactions. This is useful because some chains (e.g. Arbitrum) do not enforce this check. By default, it is set to false.

disable_fee_charge: bool

Disables fee charging for transactions. This is useful when executing eth_call for example, on OP-chains where setting the base fee to 0 isn’t sufficient. By default, it is set to false.

enable_amsterdam_eip8037: bool

Enables EIP-8037 (Amsterdam) state creation gas cost increase.

EIP-8037 introduces dual gas limits: regular gas for execution and state gas for storage creation. State gas is tracked via a reservoir model. It specifies concrete gas values based on cost_per_state_byte and adds a hash cost for deployed bytecode.

By default, it is set to false.

amsterdam_eip7708_disabled: bool

Disables EIP-7708 (ETH transfers emit logs).

By default, it is set to false.

amsterdam_eip7708_delayed_burn_disabled: bool

Disables EIP-7708 delayed burn logging.

When enabled, revm tracks all self-destructed addresses and emits logs for accounts that still have remaining balance at the end of the transaction. This can be disabled for performance reasons as it requires storing and iterating over all self-destructed accounts. When disabled, the logging can be done outside of revm when applying accounts to database state.

By default, it is set to false.

Implementations

Source

impl CfgEnv

pub fn new() -> CfgEnv

Creates new CfgEnv with default values.

Source

impl<SPEC> CfgEnv<SPEC>

pub fn spec(&self) -> &SPEC

Returns the spec for the CfgEnv.

pub fn with_chain_id(self, chain_id: u64) -> CfgEnv<SPEC>

Consumes self and returns a new CfgEnv with the specified chain ID.

pub fn with_gas_params(self, gas_params: GasParams) -> CfgEnv<SPEC>

Sets the gas params for the CfgEnv.

pub fn set_spec(&mut self, spec: SPEC)

👎Deprecated:

Use CfgEnv::set_spec_and_mainnet_gas_params instead

Sets the spec for the CfgEnv.

pub fn set_gas_params(&mut self, gas_params: GasParams)

Sets the gas params for the CfgEnv.

pub fn enable_tx_chain_id_check(self) -> CfgEnv<SPEC>

Enables the transaction’s chain ID check.

pub fn disable_tx_chain_id_check(self) -> CfgEnv<SPEC>

Disables the transaction’s chain ID check.

pub fn with_spec(self, spec: SPEC) -> CfgEnv<SPEC>

👎Deprecated:

Use CfgEnv::with_spec_and_mainnet_gas_params instead

Sets the spec for the CfgEnv.

pub fn with_spec_and_mainnet_gas_params<OSPEC>( self, spec: OSPEC, ) -> CfgEnv<OSPEC>
where OSPEC: Into<SpecId> + Clone,

Sets the spec for the CfgEnv and the gas params to the mainnet gas params.

Automatically enables EIP-8037 for AMSTERDAM and later.

pub fn with_spec_and_gas_params<OSPEC>( self, spec: OSPEC, gas_params: GasParams, ) -> CfgEnv<OSPEC>
where OSPEC: Into<SpecId> + Clone,

Consumes self and returns a new CfgEnv with the specified spec.

Resets the gas params override function as it is generic over SPEC.

pub fn with_max_blobs_per_tx(self, max_blobs_per_tx: u64) -> CfgEnv<SPEC>

Sets the blob target

pub fn set_max_blobs_per_tx(&mut self, max_blobs_per_tx: u64)

Sets the blob target

pub fn clear_max_blobs_per_tx(&mut self)

Clears the blob target and max count over hardforks.

pub fn with_disable_priority_fee_check(self, disable: bool) -> CfgEnv<SPEC>

Sets the disable priority fee check flag.

pub fn with_disable_fee_charge(self, disable: bool) -> CfgEnv<SPEC>

Sets the disable fee charge flag.

pub fn with_disable_eip7623(self, disable: bool) -> CfgEnv<SPEC>

Sets the disable eip7623 flag.

pub fn with_enable_amsterdam_eip8037(self, enable: bool) -> CfgEnv<SPEC>

Sets the enable EIP-8037 (Amsterdam) state creation gas cost flag.

Source

impl<SPEC> CfgEnv<SPEC>
where SPEC: Into<SpecId> + Clone,

pub fn new_with_spec_and_gas_params( spec: SPEC, gas_params: GasParams, ) -> CfgEnv<SPEC>

Create new CfgEnv with default values and specified spec.

pub fn blob_base_fee_update_fraction(&mut self) -> u64

Returns the blob base fee update fraction from CfgEnv::blob_base_fee_update_fraction.

If this field is not set, return the default value for the spec.

Default values for Cancun is primitives::eip4844::BLOB_BASE_FEE_UPDATE_FRACTION_CANCUN and for Prague is primitives::eip4844::BLOB_BASE_FEE_UPDATE_FRACTION_PRAGUE.

pub fn new_with_spec(spec: SPEC) -> CfgEnv<SPEC>

Create new CfgEnv with default values and specified spec. It will create a new gas params based on mainnet spec.

Internally it will call CfgEnv::new_with_spec_and_gas_params with the mainnet gas params.

pub fn with_mainnet_gas_params(self) -> CfgEnv<SPEC>

Sets the gas params for the CfgEnv to the mainnet gas params.

If spec gets changed, calling this function would use this spec to set the mainnetF gas params.

pub fn set_spec_and_mainnet_gas_params(&mut self, spec: SPEC)

Sets the spec for the CfgEnv and the gas params to the mainnet gas params.

Automatically enables EIP-8037 for AMSTERDAM and later.